# UESLogger.
#
# <tt><b>author</b></tt> uni430
#
# <tt><b>since</b></tt> UES7-02
class Ues::Platform::Commons::UESLogger

  @logger = nil
  def initialize(logger) #:nodoc:
    if ((logger == nil) || (!logger.java_kind_of?Java::cz.ues.platform.commons.logging.UESLogger))
      raise "UES Logger must be created with valid instance of cz.ues.platform.commons.logging.UESLogger."
    end
    @logger = logger
  end

  # Logs debug message.
  #
  # <tt><b>param</b></tt> msg Message
  #
  # <tt><b>param</b></tt> throwable Exception to be logged.
  #
  # <tt><b>param</b></tt> params Message parameters
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def debug(msg, throwable=nil, *params)
    if (debug_loggable?)
      throwable = convert_to_java(throwable)
      if (params.size == 1) then begin params = params[0].to_a; rescue; end; end;
      if (params != nil) then _t = []; params.to_a.each do |_e|; _e = convert_to_java(_e); _t << _e; end; params = _t.to_java(Java::java.lang.Object); end;
      @logger.debug(msg.to_s, throwable, params)
    end
  end

  # Checks is logging debug messages is enabled.
  #
  # <tt><b>return</b></tt> True if enabled, false if not
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def isDebugLoggable()
    return @logger.isDebugLoggable()
  end
  alias debug_loggable? isDebugLoggable

  # Logs info message.
  #
  # <tt><b>param</b></tt> msg Message
  #
  # <tt><b>param</b></tt> params Message parameters
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def info(msg, *params)
    if (info_loggable?)
      if (params.size == 1) then begin params = params[0].to_a; rescue; end; end;
      if (params != nil) then _t = []; params.to_a.each do |_e|; _e = convert_to_java(_e); _t << _e; end; params = _t.to_java(Java::java.lang.Object); end;
      @logger.info(msg.to_s, params)
    end
  end

  # Checks is logging info messages is enabled.
  #
  # <tt><b>return</b></tt> True if enabled, false if not
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def isInfoLoggable()
    return @logger.isInfoLoggable()
  end
  alias info_loggable? isInfoLoggable

  # Logs warning message.
  #
  # <tt><b>param</b></tt> msg Message
  #
  # <tt><b>param</b></tt> throwable Exception to be logged
  #
  # <tt><b>param</b></tt> params Message parameters
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def warning(msg, throwable=nil, *params)
    if (warning_loggable?)
      throwable = convert_to_java(throwable)
      if (params.size == 1) then begin params = params[0].to_a; rescue; end; end;
      if (params != nil) then _t = []; params.to_a.each do |_e|; _e = convert_to_java(_e); _t << _e; end; params = _t.to_java(Java::java.lang.Object); end;
      @logger.warning(msg.to_s, throwable, params)
    end
  end

  # Checks is logging warning messages is enabled.
  #
  # <tt><b>return</b></tt> True if enabled, false if not
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def isWarningLoggable()
    return @logger.isWarningLoggable()
  end
  alias warning_loggable? isWarningLoggable

  # Logs error message.
  #
  # <tt><b>param</b></tt> msg Message
  #
  # <tt><b>param</b></tt> throwable Exception to be logged
  #
  # <tt><b>param</b></tt> params Message parameters
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def error(msg, throwable=nil, *params)
    if (error_loggable?)
      throwable = convert_to_java(throwable)
      if (params.size == 1) then begin params = params[0].to_a; rescue; end; end;
      if (params != nil) then _t = []; params.to_a.each do |_e|; _e = convert_to_java(_e); _t << _e; end; params = _t.to_java(Java::java.lang.Object); end;
      @logger.error(msg.to_s, throwable, params)
    end
  end

  # Checks is logging error messages is enabled.
  #
  # <tt><b>return</b></tt> True if enabled, false if not
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def isErrorLoggable()
    return @logger.isErrorLoggable()
  end
  alias error_loggable? isErrorLoggable

  # Logs custom message.
  #
  # <tt><b>param</b></tt> level Log level
  #
  # <tt><b>param</b></tt> msg Message
  #
  # <tt><b>param</b></tt> throwable Exception to be logged
  #
  # <tt><b>param</b></tt> params Message parameters
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def log(level, msg, throwable=nil, *params)
    if (isLoggable(level))
      throwable = convert_to_java(throwable)
      if (params.size == 1) then begin params = params[0].to_a; rescue; end; end;
      if (params != nil) then _t = []; params.to_a.each do |_e|; _e = convert_to_java(_e); _t << _e; end; params = _t.to_java(Java::java.lang.Object); end;
      @logger.log(msg.to_s, throwable, params)
    end
  end

  # Checks if logging of given level is enabled.
  #
  # <tt><b>param</b></tt> level Log level
  #
  # <tt><b>return</b></tt> True if enabled, false if not
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def isLoggable(level)
    return @logger.isLoggable(level)
  end
  alias loggable? isLoggable

  private
  def convert_to_java(value) #:nodoc:
    if (value.java_kind_of?File)
      if (value.java_kind_of?File) then value = Java::java.io.File.new(value.path) end
    elsif (value.java_kind_of?Array)
      if (value != nil) then _t = []; value.to_a.each do |_e|; _e = convert_to_java(_e); _t << _e; end; value = Java::java.util.ArrayList.new(_t); end;
    elsif ((value.java_kind_of?Fixnum) || (value.java_kind_of?Float))
      if ((value.java_kind_of?Fixnum) || (value.java_kind_of?Float)) then value = Java::java.lang.Double.new(value) end
    elsif (value.java_kind_of?Exception)
      if (value.java_kind_of?NativeException) then value = value.cause elsif (value.java_kind_of?Exception) then; _t = []; begin value.backtrace.each do |_e|; _p = _e.split(":"); _t.push(Java::java.lang.StackTraceElement.new(_p[0], "", _p[2], Integer(_p[1]))); end; rescue; end; value = Java::java.lang.Exception.new(value.message); value.setStackTrace(_t.to_java(Java::java.lang.StackTraceElement)); end;
    else
      if ((!value.java_kind_of?Java::java.lang.Object) && (value.class.method_defined?"to_java")) then value = value.to_java end
    end
    return value
  end

end
